@@ -1,5 +1,5 @@
 package Photonic::Geometry::FromB;
-$Photonic::Geometry::FromB::VERSION = '0.019';
+$Photonic::Geometry::FromB::VERSION = '0.020';
 
 =encoding UTF-8
 
@@ -39,7 +39,7 @@ use Moose;
 use MooseX::StrictConstructor;
 
 has 'B' =>(is=>'ro', isa=>'PDL', required=>1,
-	   documentation=>'Charateristic function');
+	   documentation=>'Characteristic function');
 
 with 'Photonic::Roles::Geometry';
 
@@ -55,7 +55,7 @@ Photonic::Geometry::FromB
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 SYNOPSIS
 
@@ -79,7 +79,7 @@ the values 0 for each pixel or voxel within material A and 1 within
 
 Creates a new Ph::G::FromB object
 
-$pdl is a boolean array with 1's and 0's representing the characteriztic
+$pdl is a boolean array with 1's and 0's representing the characteristic
 function within the unit cell. Its dimensions must be odd. Its number
 of dimensions is the dimension of space
 
