@@ -1,5 +1,5 @@
 package Photonic::LE::NR2::EpsL;
-$Photonic::LE::NR2::EpsL::VERSION = '0.019';
+$Photonic::LE::NR2::EpsL::VERSION = '0.020';
 
 =encoding UTF-8
 
@@ -9,7 +9,7 @@ Photonic::LE::NR2::EpsL
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 COPYRIGHT NOTICE
 
@@ -44,45 +44,22 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA  02110-1301 USA
 =head1 SYNOPSIS
 
    use Photonic::LE::NR2::EpsL;
-   my $eps=Photonic::LE::NR2::EpsL->new(nr=>$nr, nh=>$nh);
+   my $eps=Photonic::LE::NR2::EpsL->new(haydock=>$haydock, nh=>$nh);
    my $epsilonLongitudinal=$eps->evaluate($epsA, $epsB);
 
 =head1 DESCRIPTION
 
 Calculates the macroscopic longitudinal dielectric function for a given fixed
-Photonic::LE::NR2::AllH structure as a function of the dielectric
+Photonic::LE::NR2::Haydock structure as a function of the dielectric
 functions of the components. Nonretarded calculation for binary metamaterials.
 
-=head1 METHODS
+Consumes L<Photonic::Roles::EpsL>
+- please see those for attributes.
+
+=head1 ATTRIBUTES
 
 =over 4
 
-=item * new(nr=>$nr, nh=>$nh, smallE=>$smallE)
-
-Initializes the structure.
-
-$nr is a Photonic::LE::NR2::AllH structure (required).
-
-$nh is the maximum number of Haydock coefficients to use (required).
-
-$smallE is the criteria of convergence for the continued fraction
-(defaults to 1e-7)
-
-=item * evaluate($epsA, $epsB)
-
-Returns the macroscopic dielectric function for a given value of the
-dielectric functions of the host $epsA and the particle $epsB.
-
-=back
-
-=head1 ACCESSORS (read only)
-
-=over 4
-
-=item * nr
-
-The LE::NR2::AllH structure
-
 =item * epsA epsB
 
 The dielectric functions of component A and component B used in the
@@ -92,41 +69,11 @@ last calculation.
 
 The spectral variable used in the last calculation
 
-=item * epsL
-
-The longitudinal macroscopic function obtained in the last calculation.
-
-=item * nh
-
-The maximum number of Haydock coefficients to use.
-
-=item * nhActual
-
-The actual number of Haydock coefficients used in the last calculation
-
-=item * converged
-
-Flags that the last calculation converged before using up all coefficients
-
-=item * smallE
-
-Criteria of convergence for continued fraction. 0 means don't
-check.
-
 =back
 
-=begin Pod::Coverage
-
-=head2 BUILD
-
-=end Pod::Coverage
-
 =cut
 
 use namespace::autoclean;
-use PDL::Lite;
-use PDL::NiceSlice;
-use Photonic::LE::NR2::AllH;
 use Photonic::Types;
 use Photonic::Utils qw(lentzCF);
 
@@ -135,28 +82,30 @@ use List::Util qw(min);
 use Moose;
 use MooseX::StrictConstructor;
 
-has 'epsA'=>(is=>'ro', isa=>'Photonic::Types::PDLComplex', init_arg=>undef, writer=>'_epsA',
-    documentation=>'Dielectric function of host');
-has 'epsB'=>(is=>'ro', isa=>'Photonic::Types::PDLComplex', init_arg=>undef, writer=>'_epsB',
-        documentation=>'Dielectric function of inclusions');
-has 'u'=>(is=>'ro', isa=>'Photonic::Types::PDLComplex', init_arg=>undef, writer=>'_u',
-    documentation=>'Spectral variable');
 with 'Photonic::Roles::EpsL';
 
-sub evaluate {
+has 'epsA'=>(is=>'ro', isa=>'Photonic::Types::PDLComplex', required => 1,
+    documentation=>'Dielectric function of host');
+has 'epsB'=>(is=>'ro', isa=>'Photonic::Types::PDLComplex', required => 1,
+        documentation=>'Dielectric function of inclusions');
+has 'u'=>(is=>'ro', isa=>'Photonic::Types::PDLComplex', lazy => 1, builder => '_build_u',
+    documentation=>'Spectral variable');
+
+sub _build_u {
     my $self=shift;
-    $self->_epsA(my $epsA=shift);
-    $self->_epsB(my $epsB=shift);
-    $self->_u(my $u=1/(1-$epsB/$epsA));
-    my $as=PDL::r2C($self->nr->as);
-    my $b2s=PDL::r2C($self->nr->b2s);
-    my $min= min($self->nh, $self->nr->iteration);
-    my ($fn, $n)=lentzCF($u-$as, -$b2s, $min, $self->smallE);
+    1/(1-$self->epsB/$self->epsA);
+}
+
+sub _build_epsL {
+    my $self=shift;
+    my $as=PDL::r2C($self->haydock->as);
+    my $b2s=PDL::r2C($self->haydock->b2s);
+    my $min= min($self->nh, $self->haydock->iteration);
+    my ($fn, $n)=lentzCF((my $u = $self->u)-$as, -$b2s, $min, $self->smallE);
     # Check this logic:
-    $self->_converged($n<$min || $self->nr->iteration<=$self->nh);
+    $self->_converged($n<$min || $self->haydock->iteration<=$self->nh);
     $self->_nhActual($n);
-    $self->_epsL($epsA*$fn/$u);
-    return $self->epsL;
+    $self->epsA*$fn/$u;
 }
 
 __PACKAGE__->meta->make_immutable;
